@@ -106,7 +106,7 @@ user_t *user_findhandle( struct gaim_connection *gc, char *handle )
 	
 	while( u )
 	{
-		if( u->gc == gc && u->handle && strcasecmp( u->handle, handle ) == 0 )
+		if( u->gc == gc && u->handle && handle_cmp( u->handle, handle, gc->protocol ) == 0 )
 			break;
 		u = u->next;
 	}
